#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
#
# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
# $Revision: 12638 $
#
# Contributors:
#  Bear (original author)
#  Yachu

from Iuno.Util import update

from Iuppiter.DjangoUtil import (
    extendInstalledApps, extendMiddlewareClasses, patterns)

def attachSettings(settingsLocals, backends, preferred, config):
    """
    Attach 'mail' related settings to settings.py.

    @param settingsLocals locals() in settings.py.
    @param backends Backend instances.
    @param preferred Preferred backends.
    @param config Configuration settings.
    """
    extendInstalledApps(settingsLocals, (
        'django_statsd',
        'Iuno.cloud.metrics',
    ))
    
    # https://code.nuwainfo.com/trac/Mercurius/ticket/3302#ticket
    # 先註解移掉
    # extendMiddlewareClasses(
        # settingsLocals, 
        # [
            # 'django_statsd.middleware.StatsdMiddleware',
        # ], 
        # key='django.contrib.sessions.middleware.SessionMiddleware', 
        # addBefore=True
    # )
    
    # extendMiddlewareClasses(settingsLocals, [
        # 'django_statsd.middleware.StatsdMiddlewareTimer',
    # ])
    
    DEFAULT_STATSD_SETTINGS = {
        'STATSD_HOST': config.get("host", "statsd.nuwainfo.com"),
        "STATSD_PORT": config.get("post", 8125),
    }
    
    update(settingsLocals, DEFAULT_STATSD_SETTINGS)
    
def attachURLs(settings, urlpatterns):
    from django.conf.urls import url
    from Iuno.cloud.metrics.views import sendStatsd, getStatsdImage
    
    addMetricsUrl = False
    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
        if settings.IUNO_CLOUD_ENABLE:
            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
                services = settings.IUNO_CLOUD_SERVICES
                if 'metrics' in services:
                    addMetricsUrl = True
            else:
                addMetricsUrl = True
                
    if addMetricsUrl:
        urlpatterns += patterns('',
            url(r'^metrics/send/', sendStatsd, name='sendStatsd'),
            url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
        )

